@@ -7,7 +7,7 @@
 *
 *	This file part of:	SCAMP
 *
-*	Copyright:		(C) 2002-2013 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 2002-2018 IAP/CNRS/UPMC
 *
 *	License:		GNU General Public License
 *
@@ -22,7 +22,7 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SCAMP. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		12/11/2013
+*	Last modified:		11/04/2018
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -37,7 +37,6 @@
 
 #include "define.h"
 #include "globals.h"
-#include "crossid.h"
 #include "fgroup.h"
 #include "field.h"
 #include "fits/fitscat.h"
@@ -55,6 +54,55 @@
 #include LAPACKE_H
 #endif
 
+/****** check_fieldphotomoverlap **********************************************
+  PROTO int check_fieldphotomoverlap(fieldstruct *field, int instru)
+  PURPOSE Check if a field overlaps a photometric field or not.
+  INPUT ptr to the field to check,
+  photometric instrument index.
+  OUTPUT Photometric code (1 for genuine, 2 for dummy) if it overlaps, 0
+  otherwise.
+  NOTES -.
+  AUTHOR E. Bertin (IAP)
+  VERSION 19/02/2018
+ ***/
+int check_fieldphotomoverlap(fieldstruct *field, int instru)
+
+{
+    setstruct **pset,
+              *set;
+    samplestruct *samp,*samp2;
+    int  n,s;
+
+    pset = field->set;
+    for (s=field->nset; s--;)
+    {
+        set = *(pset++);
+        samp = set->sample;
+        for (n=set->nsample; n--; samp++)
+        {
+            if (samp->nextsamp)
+            {
+                samp2 = samp;
+                while ((samp2=samp2->nextsamp))
+                    if (samp2->set->field->photomflag
+                            && samp2->set->field->photomlabel==instru)
+                        return samp2->set->field->photomflag;
+            }
+            if (samp->prevsamp)
+            {
+                samp2 = samp;
+                while ((samp2=samp2->prevsamp))
+                    if (samp2->set->field->photomflag
+                            && samp2->set->field->photomlabel==instru)
+                        return samp2->set->field->photomflag;
+            }
+        }
+    }
+
+    /* No photometric field found */
+    return 0;
+}
+
 /****** photsolve_fgroups ****************************************************
 PROTO	void photsolve_fgroups(fgroupstruct **fgroups, int nfgroup)
 PURPOSE	Compute a global photometric solution among a group of fields.
@@ -708,7 +756,7 @@ INPUT	ptr to the group of fields.
 OUTPUT	-.
 NOTES	Uses the global preferences.
 AUTHOR	E. Bertin (IAP)
-VERSION	11/09/2004
+VERSION	19/02/2018
  ***/
 void	compmags_fgroup(fgroupstruct *fgroup)
   {
@@ -724,9 +772,9 @@ void	compmags_fgroup(fgroupstruct *fgroup)
   for (f=0; f<nfield; f++)
     {
     pset = fields[f]->set;
-    set = *(pset++);
-    for (s=fields[f]->nset; s--; set=*(pset++))
+    for (s=fields[f]->nset; s--;)
       {
+      set = *(pset++);
       samp = set->sample;
       for (nsamp=set->nsample; nsamp--; samp++)
         if (samp->flux>0.0)
@@ -816,6 +864,52 @@ void	avermags_fgroup(fgroupstruct *fgroup)
   return;
   }
 
+/****** check_fieldoverlap ****************************************************
+  PROTO int check_fieldoverlap(fieldstruct *field1, fieldstruct *field2)
+  PURPOSE Check if two fields overlap or not.
+  INPUT ptr to the first field,
+  ptr to the second field.
+  OUTPUT 1 if they overlap, 0 otherwise.
+  NOTES -.
+  AUTHOR E. Bertin (IAP)
+  VERSION 07/02/2005
+ **
+int check_fieldoverlap(fieldstruct *field1, fieldstruct *field2)
+
+{
+    setstruct **pset,
+              *set;
+    samplestruct *samp,*samp2;
+    int  n,s;
+
+    pset = field1->set;
+    set = *(pset++);
+    for (s=field1->nset; s--; set=*(pset++))
+    {
+        samp = set->sample;
+        for (n=set->nsample; n--; samp++)
+        {
+            if (samp->nextsamp)
+            {
+                samp2 = samp;
+                while ((samp2=samp2->nextsamp))
+                    if (samp2->set->field == field2)
+                        return 1;
+            }
+            if (samp->prevsamp)
+            {
+                samp2 = samp;
+                while ((samp2=samp2->prevsamp))
+                    if (samp2->set->field == field2)
+                        return 1;
+            }
+        }
+    }
+
+    No link found between both fields 
+    return 0;
+}
+*/
 
 /****** selecphotom_fgroup *****************************************************
 PROTO	void selecphotom_fgroup(fgroupstruct *fgroup)
