@@ -7,7 +7,7 @@
 *
 *	This file part of:	SCAMP
 *
-*	Copyright:		(C) 2002-2014 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 2002-2018 IAP/CNRS/SorbonneU
 *
 *	License:		GNU General Public License
 *
@@ -22,35 +22,24 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SCAMP. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		18/02/2014
+*	Last modified:		29/08/2018
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
+#ifndef _PREFLIST_H_
+#define _PREFLIST_H_
+
 #ifdef HAVE_CONFIG_H
 #include	"config.h"
 #endif
 
 #include "key.h"
-
-#ifndef _PREFS_H_
 #include "prefs.h"
-#endif
-
-#ifndef _CHECK_H_
 #include "check.h"
-#endif
-
-#ifndef _FGROUP_H_
+#include "dgeomap.h"
 #include "fgroup.h"
-#endif
-
-#ifndef _MATCH_H_
 #include "match.h"
-#endif
-
-#ifndef _XML_H_
 #include "xml.h"
-#endif
 
 #ifdef	USE_THREADS
 #define	THREADS_PREFMAX THREADS_NMAX
@@ -63,6 +52,8 @@ int idummy;
 pkeystruct key[] =
  {
   {"AHEADER_GLOBAL", P_STRING, prefs.ahead_global},
+  {"AHEADER_NAME", P_STRINGLIST, prefs.ahead_name, 0,0, 0.0,0.0,
+   {""}, 0, MAXFILE, &prefs.nahead_name},
   {"AHEADER_SUFFIX", P_STRING, prefs.ahead_suffix},
   {"AIRMASS_KEY", P_STRING, prefs.airmass_key},
   {"ASTR_ACCURACY", P_FLOAT, &prefs.astraccuracy,0,0, 0.0, 1e6},
@@ -74,10 +65,9 @@ pkeystruct key[] =
   {"ASTRCLIP_NSIGMA", P_FLOAT, &prefs.astrclip_nsig, 0,0, 0.0,1e31},
   {"ASTREF_BAND", P_STRING, prefs.astref_bandname},
   {"ASTREF_CATALOG", P_KEY, &prefs.astrefcat, 0,0, 0.0,0.0,
-   {"NONE", "FILE", "USNO-A1", "USNO-A2", "USNO-B1", "GSC-1.3", "GSC-2.2",
-    "GSC-2.3", "2MASS", "DENIS-3", "UCAC-1", "UCAC-2", "UCAC-3", "UCAC-4",
-    "SDSS-R3", "SDSS-R5", "SDSS-R6", "SDSS-R7", "SDSS-R8", "SDSS-R9",
-    "NOMAD-1", "PPMX", "CMC-14", "TYCHO-2", ""}},
+   {"NONE", "FILE", "USNO-A2", "USNO-B1", "GSC-2.3", "2MASS", "DENIS-3",
+    "UCAC-4", "URAT-1", "SDSS-R9", "SDSS-R12", "NOMAD-1", "PPMX", "CMC-15",
+    "TYCHO-2", "IGSL", "ALLWISE", "GAIA-DR1", "GAIA-DR2", "PANSTARRS-1", ""}},
   {"ASTREF_WEIGHT", P_FLOAT, &prefs.astref_weight, 0,0, 1e-6,1e6},
   {"ASTREFCAT_NAME", P_STRINGLIST, prefs.astref_name, 0,0,0.0,0.0,
     {""}, 0, MAXNGROUP, &prefs.nastref_name},
@@ -85,6 +75,10 @@ pkeystruct key[] =
    {""}, 2, NAXIS, &prefs.nastrefcent_key},
   {"ASTREFERR_KEYS", P_STRINGLIST, prefs.astreferr_key, 0,0, 0.0,0.0,
    {""}, 2, (NAXIS*(NAXIS+1))/2, &prefs.nastreferr_key},
+  {"ASTREFPROP_KEYS", P_STRINGLIST, prefs.astrefprop_key, 0,0, 0.0,0.0,
+   {""}, 2, NAXIS, &prefs.nastrefprop_key},
+  {"ASTREFPROPERR_KEYS", P_STRINGLIST, prefs.astrefproperr_key, 0,0, 0.0,0.0,
+   {""}, 2, NAXIS, &prefs.nastrefproperr_key},
   {"ASTREFMAG_KEY", P_STRING, prefs.astrefmag_key},
   {"ASTREFMAGERR_KEY", P_STRING, prefs.astrefmagerr_key},
   {"ASTREFOBSDATE_KEY", P_STRING, prefs.astrefobsdate_key},
@@ -92,7 +86,6 @@ pkeystruct key[] =
     {""}, 2, 2, &prefs.nastref_maglim},
   {"ASTRINSTRU_KEY", P_STRINGLIST, prefs.astrinstru_key, 0,0, 0.0,0.0,
    {""}, 0, 35, &prefs.nastrinstru_key},
-  {"CDSCLIENT_EXEC", P_STRING, &prefs.cdsclient_path},
   {"CENTROID_KEYS", P_STRINGLIST, prefs.centroid_key, 0,0,0.0,0.0,
     {""}, 2, NAXIS, &prefs.ncentroid_key},
   {"CENTROIDERR_KEYS", P_STRINGLIST, prefs.centroiderr_key, 0,0,0.0,0.0,
@@ -127,6 +120,10 @@ pkeystruct key[] =
   {"CORRECT_COLOURSHIFTS", P_BOOL, &prefs.colourshiftcorr_flag},
 //  {"CORRECT_PROPERMOTIONS", P_BOOL, &prefs.propmotioncorr_flag},
   {"CROSSID_RADIUS", P_FLOAT, &prefs.crossid_radius, 0,0, 0.0,1e31},
+  {"DGEOMAP_NAME", P_STRING, prefs.dgeomap_name},
+  {"DGEOMAP_NNEAREST", P_INT, &prefs.dgeomap_nnearest,
+	1, DGEOMAP_NNEIGHBOURMAX},
+  {"DGEOMAP_STEP", P_INT, &prefs.dgeomap_step, 1, 262144},
   {"DISTORT_KEYS", P_STRINGLIST, prefs.context_name, 0,0,0.0,0.0,
     {""}, 0, MAXCONTEXT, &prefs.ncontext_name},
   {"DISTORT_GROUPS", P_INTLIST, prefs.context_group, 1,MAXCONTEXT,0.0,0.0,
@@ -136,7 +133,6 @@ pkeystruct key[] =
   {"ELLIPTICITY_MAX", P_FLOAT, &prefs.maxellip, 0,0, 0.0, 1.0},
   {"EXPOTIME_KEY", P_STRING, prefs.expotime_key},
   {"EXTINCT_KEY", P_STRING, prefs.extcoeff_key},
-  {"FGROUP_RADIUS", P_FLOAT, &prefs.group_radius, 0,0, 0.0,180.0},
   {"FIXFOCALPLANE_NMIN", P_INT, &prefs.fixfocalplane_nmin, 0, 65535, 0.0, 0.0},
   {"FLAGS_MASK", P_INT, &prefs.sexflags_mask, 0,0xff, 0.0,0.0},
   {"FOCDISTORT_DEGREE", P_INT, &prefs.focal_deg, 1,16,0.0,0.0},
@@ -149,6 +145,8 @@ pkeystruct key[] =
   {"HEADER_SUFFIX", P_STRING, prefs.head_suffix},
   {"HEADER_TYPE", P_KEY, &prefs.header_type, 0,0, 0.0,0.0,
    {"NORMAL","FOCAL_PLANE",""}},
+  {"HEADER_NAME", P_STRINGLIST, prefs.head_name, 0,0, 0.0,0.0,
+   {""}, 0, MAXFILE, &prefs.nhead_name},
   {"IMAFLAGS_MASK", P_INT, &prefs.imaflags_mask, 0,0x7fffffff, 0.0,0.0},
   {"INCLUDE_ASTREFCATALOG", P_BOOL, &prefs.astrefinprop_flag},
   {"MAGZERO_KEY", P_STRING, prefs.magzero_key},
@@ -189,9 +187,10 @@ pkeystruct key[] =
   {"REFOUT_CATPATH", P_STRING, prefs.outref_path},
   {"REF_SERVER", P_STRINGLIST, prefs.ref_server, 0,0, 0.0,0.0,
    {""}, 0, MAX_SERVER, &prefs.nref_server},
-  {"REF_PORT", P_INTLIST, prefs.ref_port, 0,65535, 0.0,0.0,
-   {""}, 0, MAX_SERVER, &prefs.nref_port},
+  {"REF_TIMEOUT", P_FLOATLIST, prefs.ref_timeout, 0,0, 0.0,3600.0,
+   {""}, 0, MAX_SERVER, &prefs.nref_timeout},
   {"SAVE_REFCATALOG", P_BOOL, &prefs.outrefcat_flag},
+  {"SAVE_DGEOMAP", P_BOOL, &prefs.dgeomap_flag},
   {"SN_THRESHOLDS", P_FLOATLIST, prefs.sn_thresh, 0,0, 0.0,1e30,
     {""}, 2, 2, &prefs.nsn_thresh},
   {"SOLVE_ASTROM", P_BOOL, &prefs.solvastrom_flag},
@@ -217,27 +216,32 @@ char *default_prefs[] =
 "# EB " DATE,
 "#",
 " ",
-"#----------------------------- Field grouping ---------------------------------",
-" ",
-"FGROUP_RADIUS          1.0             # Max dist (deg) between field groups",
-" ",
 "#---------------------------- Reference catalogs ------------------------------",
 " ",
-"REF_SERVER         cocat1.u-strasbg.fr # Internet addresses of catalog servers",
-"*REF_PORT               80              # Ports to connect to catalog servers",
-"*CDSCLIENT_EXEC         " CDSCLIENT "         # CDSclient executable",
-"ASTREF_CATALOG          2MASS          # NONE, FILE, USNO-A1,USNO-A2,USNO-B1,",
-"                                       # GSC-1.3,GSC-2.2,GSC-2.3,",
-"                                       # TYCHO-2, UCAC-1,UCAC-2,UCAC-3,UCAC-4,",
-"                                       # NOMAD-1, PPMX, CMC-14, 2MASS, DENIS-3,",
-"                                       # SDSS-R3,SDSS-R5,SDSS-R6,SDSS-R7,",
-"                                       # SDSS-R8, SDSS-R9",
+"REF_SERVER         vizier.unistra.fr   # Internet addresses of catalog servers",
+"                                       # Possible mirrors include:",
+"                                       # vizier.nao.ac.jp,",
+"                                       # vizier.hia.nrc.ca,",
+"                                       # vizier.ast.cam.ac.uk,",
+"                                       # vizier.iucaa.in,",
+"                                       # vizier.china-vo.org,",
+"                                       # vizier.cfa.harvard.edu and",
+"                                       # viziersaao.chpc.ac.za",
+"*REF_TIMEOUT            10              # Server connection timeouts (s) 0=none",
+"ASTREF_CATALOG         2MASS           # NONE,FILE,USNO-A2,USNO-B1,GSC-2.3,",
+"                                       # TYCHO-2,UCAC-4,URAT-1,NOMAD-1,PPMX,",
+"                                       # CMC-15,2MASS,DENIS-3,SDSS-R9,SDSS-R12,",
+"                                       # IGSL,GAIA-DR1,GAIA-DR2,PANSTARRS-1,",
+"                                       # or ALLWISE",
 "ASTREF_BAND            DEFAULT         # Photom. band for astr.ref.magnitudes",
 "                                       # or DEFAULT, BLUEST, or REDDEST",
 "*ASTREFCAT_NAME         astrefcat.cat   # Local astrometric reference catalogs",
 "*ASTREFCENT_KEYS        X_WORLD,Y_WORLD # Local ref.cat. centroid parameters",
 "*ASTREFERR_KEYS         ERRA_WORLD, ERRB_WORLD, ERRTHETA_WORLD",
 "*                                       # Local ref.cat. err. ellipse params",
+"*ASTREFPROP_KEYS        PMALPHA_J2000, PMDELTA_J2000 # Local ref.cat. PM params",
+"*ASTREFPROPERR_KEYS     PMALPHAERR_J2000, PMDELTAERR_J2000",
+"*                                       # Local ref.cat. PM err. params",
 "*ASTREFMAG_KEY          MAG             # Local ref.cat. magnitude parameter",
 "*ASTREFMAGERR_KEY       MAGERR          # Local ref.cat. mag. error parameter",
 "*ASTREFOBSDATE_KEY      OBSDATE         # Local ref.cat. obs. date parameter",
@@ -250,6 +254,13 @@ char *default_prefs[] =
 "MERGEDOUTCAT_TYPE      NONE            # NONE, ASCII_HEAD, ASCII, FITS_LDAC",
 "MERGEDOUTCAT_NAME      merged.cat      # Merged output catalog filename",
 " ",
+"*#------------------------ Differential geometry maps --------------------------",
+"* ",
+"*SAVE_DGEOMAP           N               # Save differential geometry maps (Y/N)?",
+"*DGEOMAP_NAME           dgeo.fits       # Differential geometry map filename",
+"*DGEOMAP_STEP           2               # Map sampling step",
+"*DGEOMAP_NNEAREST       21              # Number of nearest neighbors",
+"* ",
 "#--------------------------- Full output catalogs ---------------------------",
 " ",
 "FULLOUTCAT_TYPE        NONE            # NONE, ASCII_HEAD, ASCII, FITS_LDAC",
@@ -319,6 +330,28 @@ char *default_prefs[] =
 "*PHOT_FLAGSMASK         0x00fc          # Photometry rejection mask on SEx FLAGS",
 "*PHOT_IMAFLAGSMASK      0x0             # Photometry rejection mask on IMAFLAGS",
 " ",
+"#----------------------------- Source selection -------------------------------",
+" ",
+"SN_THRESHOLDS          10.0,100.0      # S/N thresholds (in sigmas) for all and",
+"                                       # high-SN sample",
+"FWHM_THRESHOLDS        0.0,100.0       # FWHM thresholds (in pixels) for sources",
+"ELLIPTICITY_MAX        0.5             # Max. source ellipticity",
+"FLAGS_MASK             0x00f0          # Global rejection mask on SEx FLAGS",
+"*WEIGHTFLAGS_MASK       0x00ff          # Global rejec. mask on SEx FLAGS_WEIGHT",
+"*IMAFLAGS_MASK          0x0             # Global rejec. mask on SEx IMAFLAGS_ISO",
+" ",
+"#------------------------------- WCS headers ----------------------------------",
+" ",
+"*AHEADER_GLOBAL         scamp.ahead     # Filename of a global input header",
+"*AHEADER_NAME                           # List of input header filenames",
+"*                                       # (overrides AHEADER_SUFFIX)",
+"AHEADER_SUFFIX         .ahead          # Filename extension for additional",
+"                                       # input headers",
+"*HEADER_NAME                            # List of output header filenames",
+"*                                       # (overrides HEADER_SUFFIX)",
+"HEADER_SUFFIX          .head           # Filename extension for output headers",
+"*HEADER_TYPE            NORMAL          # NORMAL or FOCAL_PLANE",
+" ",
 "#------------------------------- Check-plots ----------------------------------",
 " ",
 "*CHECKPLOT_CKEY         SCAMPCOL        # FITS keyword for PLPLOT field colour",
@@ -332,25 +365,13 @@ char *default_prefs[] =
 "fgroups,distort,astr_interror2d,astr_interror1d,astr_referror2d,"
 "astr_referror1d,astr_chi2,psphot_error # Check-plot filename(s)",
 " ",
-"*#------------------------------- Check-images ---------------------------------",
+"*#------------------------------ Check-images ---------------------------------",
 "* ",
 "*CHECKIMAGE_TYPE        NONE            # NONE, AS_PAIR, AS_REFPAIR, or AS_XCORR",
 "*CHECKIMAGE_NAME        check.fits      # Check-image filename(s)",
 "* ",
 "#------------------------------ Miscellaneous ---------------------------------",
 " ",
-"SN_THRESHOLDS          10.0,100.0      # S/N thresholds (in sigmas) for all and",
-"                                       # high-SN sample",
-"FWHM_THRESHOLDS        0.0,100.0       # FWHM thresholds (in pixels) for sources",
-"*ELLIPTICITY_MAX        0.5             # Max. source ellipticity",
-"*FLAGS_MASK             0x00f0          # Global rejection mask on SEx FLAGS",
-"*WEIGHTFLAGS_MASK       0x00ff          # Global rejec. mask on SEx FLAGS_WEIGHT",
-"*IMAFLAGS_MASK          0x0             # Global rejec. mask on SEx IMAFLAGS_ISO",
-"*AHEADER_GLOBAL         scamp.ahead     # Filename of the global INPUT header",
-"AHEADER_SUFFIX         .ahead          # Filename extension for additional",
-"                                       # INPUT headers",
-"HEADER_SUFFIX          .head           # Filename extension for OUTPUT headers",
-"*HEADER_TYPE            NORMAL          # NORMAL or FOCAL_PLANE",
 "VERBOSE_TYPE           NORMAL          # QUIET, NORMAL, LOG or FULL",
 "WRITE_XML              Y               # Write XML file (Y/N)?",
 "XML_NAME               scamp.xml       # Filename for XML output",
@@ -362,7 +383,8 @@ char *default_prefs[] =
 "                                       # 0 = automatic",
 #else
 "NTHREADS               1               # 1 single thread",
-#endif
+#endif // USE_THREADS
 ""
  };
 
+#endif // _PREFLIST_H_
