@@ -7,7 +7,7 @@
 *
 *	This file part of:	SCAMP
 *
-*	Copyright:		(C) 2002-2012 Emmanuel Bertin -- IAP/CNRS/UPMC
+*	Copyright:		(C) 2002-2020 IAP/CNRS/SorbonneU
 *
 *	License:		GNU General Public License
 *
@@ -22,7 +22,7 @@
 *	You should have received a copy of the GNU General Public License
 *	along with SCAMP. If not, see <http://www.gnu.org/licenses/>.
 *
-*	Last modified:		11/07/2012
+*	Last modified:		19/02/2020
 *
 *%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
@@ -90,14 +90,14 @@ documentation)
 void    readprefs(char *filename, char **argkey, char **argval, int narg)
 
   {
-   FILE		*infile;
-   char		str[MAXCHARL],
-		*cp,  *keyword, *value, **dp;
-   int		i, ival, nkey, warn, argi, flagc, flagd, flage, flagz;
-   float	dval;
-#ifndef	NO_ENVVAR
-   char		value2[MAXCHARL],envname[MAXCHAR];
-   char		*dolpos;
+   FILE			*infile;
+   char			str[MAXCHARL],
+				*cp,  *keyword, *value, **dp;
+   int			i, ival, nkey, warn, argi, flagc, flagd, flage, flagz;
+   double		dval;
+#ifdef	HAVE_GETENV
+   static char		value2[MAXCHARL],envname[MAXCHAR];
+   char			*dolpos, *listbuf;
 #endif
 
 
@@ -115,8 +115,10 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
     strcpy(keylist[i], key[i].name);
   keylist[i][0] = '\0';
 
+
 /*Scan the configuration file*/
 
+  listbuf = NULL;
   argi=0;
   flagc = 0;
   flagd = 1;
@@ -149,16 +151,17 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
       else
         break;
       }
+
     keyword = strtok(str, notokstr);
     if (keyword && keyword[0]!=0 && keyword[0]!=(char)'#')
       {
-     if (warn>=10)
+      if (warn>=10)
         error(EXIT_FAILURE, "*Error*: No valid keyword found in ", filename);
       nkey = findkeys(keyword, keylist, FIND_STRICT);
       if (nkey!=RETURN_ERROR)
         {
         value = strtok((char *)NULL, notokstr);
-#ifndef	NO_ENVVAR
+#ifdef	HAVE_GETENV
 /*------ Expansion of environment variables (preceded by '$') */
         if (value && (dolpos=strchr(value, '$')))
           {
@@ -193,7 +196,7 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
               }
 	    }
 
-          value = value2;
+          value = strtok(value2, notokstr);
           }
 #endif
         switch(key[nkey].type)
@@ -201,6 +204,8 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
           case P_FLOAT:
             if (!value || value[0]==(char)'#')
               error(EXIT_FAILURE, keyword," keyword has no value!");
+            if (*value=='@')
+              value = listbuf = list_to_str(value+1);
             dval = atof(value);
             if (dval>=key[nkey].dmin && dval<=key[nkey].dmax)
               *(double *)(key[nkey].ptr) = dval;
@@ -211,6 +216,8 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
           case P_INT:
             if (!value || value[0]==(char)'#')
               error(EXIT_FAILURE, keyword," keyword has no value!");
+            if (*value=='@')
+              value = listbuf = list_to_str(value+1);
             ival = (int)strtol(value, (char **)NULL, 0);
             if (ival>=key[nkey].imin && ival<=key[nkey].imax)
               *(int *)(key[nkey].ptr) = ival;
@@ -221,12 +228,16 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
           case P_STRING:
             if (!value || value[0]==(char)'#')
               error(EXIT_FAILURE, keyword," string is empty!");
+            if (*value=='@')
+              value = listbuf = list_to_str(value+1);
             strcpy((char *)key[nkey].ptr, value);
             break;
 
           case P_BOOL:
             if (!value || value[0]==(char)'#')
               error(EXIT_FAILURE, keyword," keyword has no value!");
+            if (*value=='@')
+              value = listbuf = list_to_str(value+1);
             if ((cp = strchr("yYnN", (int)value[0])))
               *(int *)(key[nkey].ptr) = (tolower((int)*cp)=='y')?1:0;
             else
@@ -236,6 +247,8 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
           case P_KEY:
             if (!value || value[0]==(char)'#')
               error(EXIT_FAILURE, keyword," keyword has no value!");
+            if (*value=='@')
+              value = listbuf = list_to_str(value+1);
             if ((ival = findkeys(value, key[nkey].keylist,FIND_STRICT))
 			!= RETURN_ERROR)
               *(int *)(key[nkey].ptr) = ival;
@@ -244,7 +257,9 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
             break;
 
           case P_BOOLLIST:
-            for (i=0; i<MAXLIST&&value&&value[0]!=(char)'#'; i++)
+            if (value && *value=='@')
+              value = strtok(listbuf = list_to_str(value+1), notokstr);
+            for (i=0; i<MAXLIST && value && value[0]!=(char)'#'; i++)
               {
               if (i>=key[nkey].nlistmax)
                 error(EXIT_FAILURE, keyword, " has too many members");
@@ -260,11 +275,13 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
             break;
 
           case P_INTLIST:
-            for (i=0; i<MAXLIST&&value&&value[0]!=(char)'#'; i++)
+            if (value && *value=='@')
+              value = strtok(listbuf = list_to_str(value+1), notokstr);
+            for (i=0; i<MAXLIST && value && value[0]!=(char)'#'; i++)
               {
               if (i>=key[nkey].nlistmax)
                 error(EXIT_FAILURE, keyword, " has too many members");
-              ival = strtol(value, (char **)NULL, 0);
+              ival = (int)strtol(value, (char **)NULL, 0);
               if (ival>=key[nkey].imin && ival<=key[nkey].imax)
                 ((int *)key[nkey].ptr)[i] = ival;
               else
@@ -277,7 +294,9 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
             break;
 
           case P_FLOATLIST:
-            for (i=0; i<MAXLIST&&value&&value[0]!=(char)'#'; i++)
+            if (value && *value=='@')
+              value = strtok(listbuf = list_to_str(value+1), notokstr);
+            for (i=0; i<MAXLIST && value && value[0]!=(char)'#'; i++)
               {
               if (i>=key[nkey].nlistmax)
                 error(EXIT_FAILURE, keyword, " has too many members");
@@ -294,6 +313,8 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
             break;
 
           case P_KEYLIST:
+            if (value && *value=='@')
+              value = strtok(listbuf = list_to_str(value+1), notokstr);
             for (i=0; i<MAXLIST && value && value[0]!=(char)'#'; i++)
               {
               if (i>=key[nkey].nlistmax)
@@ -311,6 +332,8 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
             break;
 
           case P_STRINGLIST:
+            if (value && *value=='@')
+              value = strtok(listbuf = list_to_str(value+1), notokstr);
             if (!value || value[0]==(char)'#')
               {
               value = "";
@@ -326,6 +349,8 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
               QMALLOC(((char **)key[nkey].ptr)[i], char, MAXCHAR);
               strcpy(((char **)key[nkey].ptr)[i], value);
               value = strtok((char *)NULL, notokstr);
+              if (flagz)
+                break;
               }
             if (i<key[nkey].nlistmin)
               error(EXIT_FAILURE, keyword, " list has not enough members");
@@ -337,6 +362,11 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
 				" in readprefs()");
             break;
           }
+        if (listbuf)
+          {
+          free(listbuf);
+          listbuf = NULL;
+          }
         key[nkey].flag = 1;
         }
       else
@@ -357,7 +387,7 @@ void    readprefs(char *filename, char **argkey, char **argval, int narg)
   }
 
 
-/********************************* findkey **********************************/
+/********************************* findkeys **********************************/
 /*
 find an item within a list of keywords.
 */
@@ -381,7 +411,7 @@ case-insensitive strcmp.
 int	cistrcmp(char *cs, char *ct, int mode)
 
   {
-   int  i, diff;
+   int	i, diff;
 
   if (mode)
     {
@@ -400,6 +430,48 @@ int	cistrcmp(char *cs, char *ct, int mode)
   }
 
 
+/****** list_to_str **********************************************************
+PROTO	char	*list_to_str(char *listname)
+PURPOSE	Read the content of a file and convert it to a long string.
+INPUT	File name.
+OUTPUT	Pointer to an allocated string, or NULL if something went wrong.
+NOTES	-.
+AUTHOR	E. Bertin (IAP)
+VERSION	06/02/2008
+ ***/
+char	*list_to_str(char *listname)
+  {
+   FILE	*fp;
+   char		liststr[MAXCHAR],
+		*listbuf, *str;
+   int		l, bufpos, bufsize;
+
+  if (!(fp=fopen(listname,"r")))
+    error(EXIT_FAILURE, "*Error*: File not found: ", listname);
+  bufsize = 8*MAXCHAR;
+  QMALLOC(listbuf, char, bufsize);
+  for (bufpos=0; fgets(liststr,MAXCHAR,fp);)
+    for (str=NULL; (str=strtok(str? NULL: liststr, "\n\r\t "));)
+      {
+      if (bufpos>MAXLISTSIZE)
+        error(EXIT_FAILURE, "*Error*: Too many parameters in ", listname);
+      l = strlen(str)+1;
+      if (bufpos+l > bufsize)
+        {
+        bufsize += 8*MAXCHAR;
+        QREALLOC(listbuf, char, bufsize);
+        }
+      if (bufpos)
+        listbuf[bufpos-1] = ' ';
+      strcpy(listbuf+bufpos, str);
+      bufpos += l;
+      }
+  fclose(fp);
+
+  return listbuf;
+  }
+
+
 /********************************* useprefs *********************************/
 /*
 Update various structures according to the prefs.
@@ -410,15 +482,11 @@ void	useprefs(void)
    FILE			*testfile;
    char			teststr[80],str[80],
 			*pstr;
-   unsigned short	ashort=1;
    int			i, flag;
 #ifdef USE_THREADS
    int			nproc;
 #endif
 
-/* Test if byteswapping will be needed */
-  bswapflag = *((char *)&ashort);
-
 /* Multithreading */
 #ifdef USE_THREADS
   if (prefs.nthreads <= 0)
@@ -481,24 +549,26 @@ void	useprefs(void)
 /* Override INTEL CPU detection routine to help performance on 3rd-party CPUs */
 #if defined(__INTEL_COMPILER) && defined (USE_CPUREDISPATCH)
   __get_cpuid(1, &eax, &ebx, &ecx, &edx);
-  if (ecx&bit_AVX)
+  if (ebx&bit_AVX2)
+    __intel_cpu_indicator = 0x40000;
+  else if (ecx&bit_AVX)
     __intel_cpu_indicator = 0x20000;
   else if (ecx&bit_SSE4_2)
-    __intel_cpu_indicator = 0x8000;
+    __intel_cpu_indicator = 0x08000;
   else if (ecx&bit_SSE4_1)
-    __intel_cpu_indicator = 0x2000;
+    __intel_cpu_indicator = 0x02000;
   else if (ecx&bit_SSSE3)
-    __intel_cpu_indicator = 0x1000;
+    __intel_cpu_indicator = 0x01000;
   else if (ecx&bit_SSE3)
-    __intel_cpu_indicator = 0x0800;
+    __intel_cpu_indicator = 0x00800;
   else if (edx&bit_SSE2)
-    __intel_cpu_indicator = 0x0200;
+    __intel_cpu_indicator = 0x00200;
   else if (edx&bit_SSE)
-    __intel_cpu_indicator = 0x0080;
+    __intel_cpu_indicator = 0x00080;
   else if (edx&bit_MMX)
-    __intel_cpu_indicator = 0x0008;
+    __intel_cpu_indicator = 0x00008;
   else
-    __intel_cpu_indicator = 0x0001;
+    __intel_cpu_indicator = 0x00001;
 #endif
 
 /* Deactivate virtual memory mapping */
@@ -506,6 +576,14 @@ void	useprefs(void)
   mallopt(M_MMAP_MAX, 0);
 #endif
 
+/*------------------------- Check header filenames -------------------------*/ 
+  if (prefs.nahead_name && prefs.nahead_name != prefs.nfile)
+    warning("The numbers of input headers and catalogs do not match: ",
+		"the last catalogs will rely only on the aheader suffix");
+  if (prefs.nhead_name && prefs.nhead_name != prefs.nfile)
+    warning("The numbers of output headers and catalogs do not match: ",
+		"the last catalogs will rely only on the header suffix");
+
 /*---------------------------- Measurement arrays --------------------------*/
   strcpy(prefs.photflux_rkey, prefs.photflux_key);
   strtok(prefs.photflux_rkey,"([{}])");
@@ -538,8 +616,17 @@ void	useprefs(void)
   prefs.match_resol *= ARCSEC/DEG;		/* convert arcsec to degrees */
 
 /* Reference catalog servers */
-  for (i=prefs.nref_port; i<prefs.nref_server; i++)
-    prefs.ref_port[i] = prefs.ref_port[prefs.nref_port-1];
+  for (i=0; i<prefs.nref_server; i++)
+    if (!strcmp(prefs.ref_server[i], "cocat1.u-strasbg.fr")) {
+      warning("Obsolete configuration; ",
+	 "replacing cocat1.u-strasbg.fr with vizier.u-strasbg.fr");
+      strcpy(prefs.ref_server[i], "vizier.u-strasbg.fr");
+    }
+
+  for (i=prefs.nref_ntries; i<prefs.nref_server; i++)
+    prefs.ref_ntries[i] = prefs.ref_ntries[prefs.nref_ntries-1];
+  for (i=prefs.nref_timeout; i<prefs.nref_server; i++)
+    prefs.ref_timeout[i] = prefs.ref_timeout[prefs.nref_timeout-1];
 
 /* Astrometric matching */
   for (i=prefs.nmosaic_type; i<MAXASTRINSTRU; i++)
